#version 460 core
layout (location = 0) in vec3 aPos;
layout (location = 1) in vec3 aNormal;
layout (location = 2) in vec2 aTex;
layout (location = 3) in vec3 aTangent;
layout (location = 4) in vec3 aBitangent;

// Outputs the current position for the Fragment Shader
out vec3 crntPos;
// Outputs the normal for the Fragment Shader
out vec3 Normal;
// Outputs the texture coordinates to the Fragment Shader
out vec2 texCoord;
// Outputs the position of the directional light to the Fragment Shader (for shadow map)
out vec4 DirectionalLightSpacePos;

uniform mat4 view;
uniform mat4 projection;
uniform mat4 model;

uniform mat4 directionalLightTransform;

void main()
{
	// calculates current position
	crntPos = vec3(model * vec4(aPos, 1.0f));

	// Assigns the normal from the Vertex Data to "Normal"
	Normal = aNormal;

	// Assigns the texture coordinates from the Vertex Data to "texCoord"
	texCoord = aTex;

	// Shadow map
	DirectionalLightSpacePos = directionalLightTransform * vec4(crntPos, 1.0);
	
	// Outputs the positions/coordinates of all vertices
	gl_Position = projection * view * vec4(crntPos, 1.0);
}